@@ -50,10 +50,12 @@ def get_options(validators):
     return options
 
 
-def join_classes(a, b):
-    a = [] if a is None else a.split() if isinstance(a, str) else a
-    b = [] if b is None else b.split() if isinstance(b, str) else b
-    return " ".join([cls for cls in list(sorted(set(a + b))) if cls.strip()])
+def join_classes(*args):
+    lists = [[] if a is None else a.split() if isinstance(a, str) else a for a in args]
+    classes = set(
+        cls.strip() for classlist in lists for cls in classlist if cls.strip()
+    )
+    return " ".join(sorted(classes))
 
 
 class Widget:
@@ -125,9 +127,12 @@ class CheckboxWidget:
 
 class ListWidget:
     def make(self, field, value, error, title, placeholder="", readonly=False):
-        if field.type == 'list:string': _class = 'type-list-string'
-        elif field.type == 'list:integer': _class = 'type-list-integer'
-        else: _class = ""
+        if field.type == "list:string":
+            _class = "type-list-string"
+        elif field.type == "list:integer":
+            _class = "type-list-integer"
+        else:
+            _class = ""
 
         return INPUT(
             _value=json.dumps(value or []),
@@ -278,6 +283,7 @@ class FormStyleFactory:
         readonly,
         deletable,
         noncreate,
+        show_id,
         kwargs=None,
     ):
         kwargs = kwargs if kwargs else {}
@@ -351,16 +357,21 @@ class FormStyleFactory:
             title = field._title if "_title" in field.__dict__ else None
             field_disabled = False
 
-            # only diplay field if readable or writable
+            # only display field if readable or writable
             if not field.readable and not field.writable:
                 continue
 
-            # if this is a reaonly field only show readable fields
+            # if this is a readonly field only show readable fields
             if readonly:
                 if not field.readable:
                     continue
 
-            # if this is an create form (unkown id) then only show writable fields. Some if an edit form was made from a list of fields and noncreate=True
+            # do not show the id if not desired
+            if field.type == "id" and not show_id:
+                continue
+
+            #  if this is an create form (unkown id) then only show writable fields.
+            #  Some if an edit form was made from a list of fields and noncreate=True
             elif not vars.get("id") and noncreate:
                 if not field.writable:
                     continue
@@ -690,6 +701,7 @@ class Form(object):
         lifespan=None,
         signing_info=None,
         submit_value="Submit",
+        show_id=True,
         **kwargs
     ):
         self.param = Param(
@@ -725,6 +737,7 @@ class Form(object):
         self.validation = validation
         self.lifespan = lifespan
         self.csrf_protection = csrf_protection
+        self.show_id = show_id
         # initialized and can change
         self.vars = {}
         self.errors = {}
@@ -739,12 +752,13 @@ class Form(object):
 
         self.kwargs = kwargs if kwargs else {}
 
-        if readonly or request.method == "GET":
-            if self.record:
-                self.vars = self._read_vars_from_record(table)
-        else:
+        if self.record:
+            self.vars = self._read_vars_from_record(table)
+        if not readonly and request.method != "GET":
             post_vars = request.POST
-            self.vars = copy.deepcopy(request.forms)
+            form_vars = copy.deepcopy(request.forms)
+            for k in form_vars:
+                self.vars[k] = form_vars[k]
             self.submitted = True
             process = False
 
@@ -902,6 +916,7 @@ class Form(object):
                 self.readonly,
                 self.deletable,
                 self.noncreate,
+                show_id=self.show_id,
                 kwargs=self.kwargs,
             )
             for item in self.param.sidecar:
